<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>FindAnnotationCollocationsDialog</name>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="13"/>
        <source>dialog_tittle</source>
        <translation>Find groups of annotated regions</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="82"/>
        <source>region_size_label</source>
        <translation>Region size:</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="124"/>
        <source>search_button</source>
        <translation>Search</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="148"/>
        <source>save_annotations_button</source>
        <translation>Save regions as annotations..</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="155"/>
        <source>clear_results_button</source>
        <translation>Clear resutls</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="188"/>
        <source>cancel_button</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="44"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="49"/>
        <source>2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="168"/>
        <source>whole annotations</source>
        <translation>Annotation must fit into region</translation>
    </message>
</context>
<context>
    <name>U2::AnnotatorPlugin</name>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="32"/>
        <source>dna_annotator_plugin</source>
        <translation>DNA Annotator</translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="32"/>
        <source>dna_annotator_plugin_desc</source>
        <translation>This plugin contains routines to manipulate and search DNA sequence annotations</translation>
    </message>
</context>
<context>
    <name>U2::AnnotatorViewContext</name>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="62"/>
        <source>Find annotated regions...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="80"/>
        <source>warning</source>
        <translation>Warning!</translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="80"/>
        <source>no_annotations_found</source>
        <translation>No annotations found!</translation>
    </message>
</context>
<context>
    <name>U2::CollocationSearchTask</name>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="288"/>
        <location filename="../src/CollocationsDialogController.cpp" line="313"/>
        <source>collocation_search_task</source>
        <translation>Search for annotated regions</translation>
    </message>
</context>
<context>
    <name>U2::CollocationsDialogController</name>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="37"/>
        <source>click_to_add_new_annotation</source>
        <translation>&lt;&lt;click &apos;+&apos; button to add new annotation&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="71"/>
        <source>stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="71"/>
        <source>cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="77"/>
        <source>searching__found_%1_items_progress_%2</source>
        <translation>Searching... found %1 regions. Progress: %2%</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="79"/>
        <source>found_%1_items</source>
        <translation>Found %1 regions</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="81"/>
        <source>ready</source>
        <translation>Ready</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="81"/>
        <source>select_annotations</source>
        <translation>Select annotation names to search</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="100"/>
        <source>no_more_annotations_left</source>
        <translation>No annotations left</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::CollocationPrompter</name>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="107"/>
        <source> sequence from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="110"/>
        <source> set of annotations from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="117"/>
        <source>For each %1 and %2,</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="119"/>
        <source>For each %1%2,</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="134"/>
        <source> Annotations themselves may not span beyond the region.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="138"/>
        <source>%1 look if &lt;u&gt;%2&lt;/u&gt; annotations appear collocated within same region of length &lt;u&gt;%3&lt;/u&gt;.%4&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%5&lt;/u&gt;.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::CollocationWorker</name>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="205"/>
        <source>Found %1 collocations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="71"/>
        <source>Group annotations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="76"/>
        <source>Result annotation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="77"/>
        <source>Group of annotations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="78"/>
        <source>Region size</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="79"/>
        <source>Must fit into region</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="86"/>
        <source>Collocation search</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="44"/>
        <source>At least 2 annotations are required for collocation search.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="71"/>
        <source>Annotated regions containing found collocations.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="76"/>
        <source>Name of the result annotations to mark found collocations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="77"/>
        <source>A list of annotation names to search. Found regions will contain all the named annotations.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="78"/>
        <source>Effectively this is the maximum allowed distance between the interesting annotations in a group</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="79"/>
        <source>Whether the interesting annotations should entirely fit into the specified region to form a group</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="87"/>
        <source>Finds groups of specified annotations in each supplied set of annotations, stores found regions as annotations.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="66"/>
        <source>Input data</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="67"/>
        <source>An input sequence and a set of annotations to search in.</source>
        <translation></translation>
    </message>
</context>
</TS>
